from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class GKEDisabledLegacyAuth(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Legacy Authorization is set to Disabled on Kubernetes Engine Clusters"
        id = "CKV_GCP_7"
        supported_resources = ['google_container_cluster']
        categories = [CheckCategories.KUBERNETES]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        """
            Looks for monitoring configuration on google_container_cluster:
            https://www.terraform.io/docs/providers/google/r/container_cluster.html
        :param conf: google_container_cluster configuration
        :return: <CheckResult>
        """
        if 'enable_legacy_abac' in conf:
            if conf['enable_legacy_abac'][0]:
                return CheckResult.FAILED
        return CheckResult.PASSED


check = GKEDisabledLegacyAuth()



from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class SecurityCenterEmailAlertAdmins(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure that 'Send email notification for high severity alerts' is set to 'On'"
        id = "CKV_AZURE_22"
        supported_resources = ['azurerm_security_center_contact"']
        categories = [CheckCategories.GENERAL_SECURITY]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'alerts_to_admins'


check = SecurityCenterEmailAlertAdmins()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.cloudformation.checks.resource.base_resource_check import BaseResourceCheck

class cloudwatchLogGroupRetention(BaseResourceCheck):
    def __init__(self):
        name = "Ensure cloudwatch log groups specify retention days"
        id = "CKV_AWS_66"
        supported_resource = ['AWS::Logs::LogGroup']
        categories = [CheckCategories.LOGGING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resource)

    def scan_resource_conf(self, conf):
        """
            Looks for retention days in cloudwatch log group :
            https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-logs-loggroup.html#cfn-cwl-loggroup-retentionindays
        :param conf: AWS::Logs::LogGroup configuration
        :return: <CheckResult>
        """

        if 'Properties' in conf.keys():
            if 'RetentionInDays' in conf['Properties'].keys():
                return CheckResult.PASSED
        return CheckResult.FAILED


check = cloudwatchLogGroupRetention()



from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories


class GoogleComputeProjectOSLogin(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure oslogin is enabled for a Project"
        id = "CKV_GCP_33"
        supported_resources = ['google_compute_project_metadata']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'metadata/[0]/enable-oslogin'



check = GoogleComputeProjectOSLogin()



from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck
from checkov.common.models.enums import CheckResult, CheckCategories


class GoogleComputeExternalIP(BaseResourceCheck):
    def __init__(self):
        name = "Ensure that Compute instances do not have public IP addresses"
        id = "CKV_GCP_40"
        supported_resources = ['google_compute_instance']
        categories = [CheckCategories.NETWORKING]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if 'access_config' in conf.keys():
            return CheckResult.FAILED
        return CheckResult.PASSED

check = GoogleComputeExternalIP()
